<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>SeekOption</name>
    <message>
        <location filename="../seekoption.cpp" line="29"/>
        <source>Seek to position in the current track</source>
        <translation>Doorspoelen naar positie in huidig nummer</translation>
    </message>
    <message>
        <location filename="../seekoption.cpp" line="30"/>
        <source>Seek forward</source>
        <translation>Vooruitspoelen</translation>
    </message>
    <message>
        <location filename="../seekoption.cpp" line="31"/>
        <source>Seek backwards</source>
        <translation>Terugspoelen</translation>
    </message>
</context>
</TS>
